# tegridy-tools

***

### All Tegridy tools as Python modules because there is never enough tegridy ;)

***
### Install:

### git clone https://github.com/asigalov61/tegridy-tools

***

### Main tegridy-tools repository for large packages/modules is located here:

### https://1drv.ms/u/s!Ao9gnMkvUA2KgY9Ftz4xsTyiCa4TGA?e=29eMZw
